==> 0.0.3.tar.gz: lib/API/PIA_API_Page.dart <==
import 'package:dio/src/dio_error.dart';
import 'package:flutter/material.dart';
import 'package:pia_framework/API/PIA_API_Widget.dart';
import 'package:pia_framework/Variable/PIA_Global.dart';


class PIA_API_Page_CallBack
{    Widget API_Page_item(Map<String,dynamic> json) {}

/* example for callback
 return new Padding(padding: EdgeInsets.all(0),
      child: new ListTile(
      //leading: PIA_Image("Asset/Image/company.png",50,50,0,BoxFit.cover),
      title: new Text(sdata["api"],style:new TextStyle(color: (sdata["isclick"] == "1" ) ? Colors.blue : Colors.pink)),
      subtitle: (sdata["isclick"] == "1") ? PIA_Image("Asset/Image/company.png",150,150,0,BoxFit.cover): null,
          onTap: (){
        if(sdata["isclick"] != "1")
          {  sdata["isclick"] = "1"; }
         else
          {  sdata["isclick"] = ""; }

        updatestate(null);
      },
    ));
*/
}

class PIA_API_Page extends StatefulWidget
{  String url;
   Map<String,String> post;
   PIA_API_Page_CallBack callback;

   PIA_API_Page({Key key, this.url,this.post,this.callback}) : super(key: key);

   @override
   State<StatefulWidget> createState() {
     // TODO: implement createState

     if(post == null)
       { post = Map<String,String>(); }

   return PIA_API_Page_State();
  }
}


class PIA_API_Page_State  extends  State<PIA_API_Page> implements PIA_API_CallBack {

  bool firstload = true;
  var sdata;

  @override
  Widget build(BuildContext context) {
    print("PIA_API_Page $firstload " + " post:" + widget.post.toString());

    if (firstload) {
      return PIA_API_Widget(url: widget.url, post: widget.post, callback: this);
    }

    return widget.callback.API_Page_item(sdata);
  }

  @override
  void API_Error(DioErrorType error) {
    // TODO: implement API_Error
  }

  @override
  void API_Success(Map<String, dynamic> json, List j) {
    firstload = false;
    setState(() {
       sdata = json;
    });
  }

  @override
  void API_Upload_prodcess(int upload, int total) {
    // TODO: implement API_Upload_prodcess
  }

}

==> 0.0.5.tar.gz: lib/API/PIA_API_Page.dart <==
import 'package:dio/src/dio_error.dart';
import 'package:flutter/material.dart';
import 'package:pia_framework/API/PIA_API_Widget.dart';
import 'package:pia_framework/Lang/PIA_Lang.dart';
import 'package:pia_framework/Variable/PIA_Global.dart';


class PIA_API_Page_CallBack
{    Widget API_Page_item(Map<String,dynamic> json) {}

/* example for callback
 return new Padding(padding: EdgeInsets.all(0),
      child: new ListTile(
      //leading: PIA_Image("Asset/Image/company.png",50,50,0,BoxFit.cover),
      title: new Text(sdata["api"],style:new TextStyle(color: (sdata["isclick"] == "1" ) ? Colors.blue : Colors.pink)),
      subtitle: (sdata["isclick"] == "1") ? PIA_Image("Asset/Image/company.png",150,150,0,BoxFit.cover): null,
          onTap: (){
        if(sdata["isclick"] != "1")
          {  sdata["isclick"] = "1"; }
         else
          {  sdata["isclick"] = ""; }

        updatestate(null);
      },
    ));
*/
}

class PIA_API_Page extends StatefulWidget
{  String url;
Map<String,String> post;
PIA_API_Page_CallBack callback;

PIA_API_Page({Key key, this.url,this.post,this.callback}) : super(key: key);

@override
State<StatefulWidget> createState() {
  // TODO: implement createState

  if(post == null)
  { post = Map<String,String>(); }

  return PIA_API_Page_State();
}
}


class PIA_API_Page_State  extends  State<PIA_API_Page> implements PIA_API_CallBack {

  var sdata;

  @override
  Widget build(BuildContext context) {
    print("PIA_API_Page  post:" + widget.post.toString());
    if(sdata == null)
    { return PIA_API_Widget(url: widget.url, post: widget.post, callback: this);}
    else
    { return widget.callback.API_Page_item(sdata); }
  }

  @override
  void API_Error(DioErrorType error) {
    // TODO: implement API_Error
  }

  @override
  void API_Success(Map<String, dynamic> json, List j) {
    setState(() {
      sdata = json;
    });
  }

  @override
  void API_Upload_prodcess(int upload, int total) {
    // TODO: implement API_Upload_prodcess
  }

}
